@@ -1,23 +1,47 @@
 import os
 
-from dapla.jupyterextensions.authextension import AuthClient
+from dapla.jupyterextensions.authextension import AuthClient, AuthError
 from dapla.services.reader import DataSourceReader
 from dapla.services.writer import DataSourceWriter
 
 
-def read_pandas(path):
+def read_pandas(path, columns=None):
+    """
+    Read Parquet data from a path in Dapla.
+
+    Parameters
+    ----------
+    path : str
+        A path that will be mapped to a GCS path in Dapla
+    columns : List[str], optional
+        Subset of columns to read.
+
+    Returns
+    -------
+    pyarrow.Table
+        Content as a table (of columns).
+    """
     reader = DataSourceReader(AuthClient.get_access_token, os.environ['DATA_ACCESS_URL'],  os.environ['CATALOG_URL'])
-    return reader.read(path)
+    try:
+        return reader.read(path, columns)
+    except AuthError as err:
+        err.print_warning()
 
 
 def show(path):
     reader = DataSourceReader(AuthClient.get_access_token, os.environ['DATA_ACCESS_URL'],  os.environ['CATALOG_URL'])
-    return reader.list(path)
+    try:
+        return reader.list(path)
+    except AuthError as err:
+        err.print_warning()
 
 
 def details(path):
     reader = DataSourceReader(AuthClient.get_access_token, os.environ['DATA_ACCESS_URL'],  os.environ['CATALOG_URL'])
-    return reader.details(path)
+    try:
+        return reader.details(path)
+    except AuthError as err:
+        err.print_warning()
 
 
 def write_pandas(df, path, **option_kwargs):
@@ -29,4 +53,7 @@ def write_pandas(df, path, **option_kwargs):
         os.environ['METADATA_PUBLISHER_TOPIC_NAME'],
         os.environ['CATALOG_URL']
     )
-    writer.write(df, path, **option_kwargs)
+    try:
+        writer.write(df, path, **option_kwargs)
+    except AuthError as err:
+        err.print_warning()
